@@ -78,3 +78,13 @@ pub fn app() -> App<'static> {
                 .default_value("60"),
         )
 }
+
+#[cfg(test)]
+mod tests {
+    use super::app;
+
+    #[test]
+    fn package_name() {
+        assert_eq!(app().get_name(), env!("CARGO_PKG_NAME"));
+    }
+}
